@@ -59,15 +59,7 @@ class KitsuAPIWrapper(flow.Object):
         gazu.client.set_tokens(tokens)
 
     def host_is_valid(self):
-        if not gazu.client.host_is_up(gazu.client.default_client):
-            return False
-        try:
-            gazu.client.post("auth/login", {"email": "", "password": ""})
-        except Exception as exc:
-            return (
-                type(exc) == gazu.exception.ParameterException
-                or type(exc) == gazu.exception.ServerErrorException
-            )
+        return gazu.client.host_is_valid()
     
     def get_user_login(self, user_mapped_name):
         kitsu_login = None
@@ -309,9 +301,13 @@ class KitsuAPIWrapper(flow.Object):
         
         return task['task_status']['name']
     
-    def get_shot_task_types(self):
+    def get_shot_task_types(self, entity_type=None):
         types = gazu.task.all_task_types()
-        return [t['name'] for t in types if t['for_shots']]
+        types =  [
+            t['name'] for t in types
+            if entity_type is None or t['for_entity'] == entity_type
+        ]
+        return types
     
     def get_user(self, project_user_name=None):
         if project_user_name is None:
@@ -514,7 +510,7 @@ class KitsuBindings(flow.Object):
         kitsu_api = self.root().project().kitsu_api()
         entities_data = {
             'shot': ['shot', 'sequence'],
-            'asset': ['asset_name'],
+            'asset': ['asset'],
         }
         
         entity_data = {}
@@ -537,7 +533,7 @@ class KitsuBindings(flow.Object):
         if entity_type == 'shot':
             return self._kitsu_api().get_shot_data(entity_data['shot'], entity_data['sequence'])
         elif entity_type == 'asset':
-            return self._kitsu_api().get_asset_data(entity_data['asset_name'])
+            return self._kitsu_api().get_asset_data(entity_data['asset'])
         else:
             return None
 
