@@ -5,7 +5,7 @@ from kabaret.flow_entities.entities import Entity, Property
 
 from ..utils.kabaret.flow_entities.entities import EntityView
 
-from .file import FileSystemMap, TrackedFile
+from .file import FileSystemMap, TrackedFile, FileSystemRefs
 from .maputils import SimpleCreateAction
 from .task_manager import CreateTaskDefaultFiles, ManageTasksAction, FileTypeValue
 
@@ -36,7 +36,12 @@ class Task(Entity):
         action_submenus=True,
         items_action_submenus=True
     )
-    default_edit_file = flow.Connection(TrackedFile).ui(hidden=True)
+    file_refs = flow.Child(FileSystemRefs).ui(
+        expanded=True,
+        action_submenus=True,
+        items_action_submenus=True
+    )
+    active_file = flow.Connection(TrackedFile).ui(hidden=True)
     priority_actions  = Property().ui(hidden=True)
 
     @classmethod
@@ -54,11 +59,14 @@ class Task(Entity):
     
     def get_sized_icon(self, size=IconSize.SMALL):
         if size == IconSize.SMALL:
-            return self.icon_small.get()
+            icon = self.icon_small.get()
         elif size == IconSize.MEDIUM:
-            return self.icon_medium.get()
+            icon = self.icon_medium.get()
         else:
-            return self.icon_large.get()
+            icon = self.icon_large.get()
+        
+        return icon and tuple(icon)
+
     
     def get_display_name(self):
         name = self.display_name.get()
