@@ -695,7 +695,7 @@ class DefaultTask(flow.Object):
             tp = mgr.task_templates[self.template.get()]
             icon = tp.icon.get()
         
-        return icon
+        return tuple(icon)
     
     def get_display_name(self):
         return self.display_name.get()
@@ -729,7 +729,7 @@ class DefaultTasks(flow.Map):
     
     def _fill_row_style(self, style, item, row):
         style['icon'] = item.get_icon()
-        style['foreground-color'] = item.get_color()
+        style['background-color'] = item.get_color()
 
 
 # Task templates
@@ -780,7 +780,7 @@ class TaskTemplates(flow.Map):
     
     def _fill_row_style(self, style, item, row):
         style['icon'] = item.icon.get()
-        style['foreground-color'] = item.color.get()
+        style['background-color'] = item.color.get()
 
 
 # Task creation
