@@ -327,6 +327,11 @@ class TaskData:
             for a in self.session.cmds.Flow.get_object_actions(self.oid)
             if not a[3]['ui']['hidden']
         ]
+        self.file_actions = [
+            ActionData(a[3]['oid'], a[3]['ui'])
+            for a in self.session.cmds.Flow.get_object_actions(self.oid+'/files')
+            if not a[3]['ui']['hidden']
+        ]
     
     def create_file_data(self, oid, goto_oid=None, is_ref=False):
         activate_oid = self.session.cmds.Flow.call(oid, 'activate_oid', [], {}) or None
@@ -410,6 +415,9 @@ class Controller:
     def task_actions(self):
         return self.cache.actions
     
+    def task_file_actions(self):
+        return self.cache.file_actions
+    
     def file_data(self, file_type, row):
         return self.cache.files[file_type][row]
     
