@@ -228,6 +228,37 @@ class FileList(QtWidgets.QTableView):
             self.controller.show_action_dialog(data.activate_oid)
 
 
+class FileListActionsWidget(QtWidgets.QWidget):
+    """
+    Holds actions related to a file list widget.
+    """
+    def __init__(self, flow_page, controller):
+        super(FileListActionsWidget, self).__init__()
+        self.controller = controller
+        self.flow_page = flow_page
+        self.build()
+    
+    def build(self):
+        hlo = QtWidgets.QHBoxLayout()
+        hlo.addStretch(1)
+
+        for fa in self.controller.task_file_actions():
+            b = QtWidgets.QPushButton('')
+            b.setIcon(resources.get_icon(fa.icon))
+            b.setToolTip(fa.label)
+            b.setFixedWidth(40)
+            # b.setStyleSheet('background-color: rgba(255, 255, 255, 0);')
+            b.clicked.connect(lambda checked=False, a=fa: self._on_action_menu_triggered(a))
+            hlo.addWidget(b)
+        
+        hlo.setSpacing(0)
+        hlo.setMargin(0)
+        self.setLayout(hlo)
+
+    def _on_action_menu_triggered(self, action):
+        self.flow_page.show_action_dialog(action.oid)
+
+
 class FileListsWidget(QtWidgets.QWidget):
     """
     Displays the task's input, output and working files.
@@ -242,14 +273,16 @@ class FileListsWidget(QtWidgets.QWidget):
         self.file_lists['Inputs'] = FileList(self.task_widget, 'Inputs')
         self.file_lists['Works'] = FileList(self.task_widget, 'Works')
         self.file_lists['Outputs'] = FileList(self.task_widget, 'Outputs')
+        self.file_buttons = FileListActionsWidget(self.task_widget.page, self.task_widget.controller)
 
-        hlo = QtWidgets.QHBoxLayout()
-        hlo.addWidget(self.file_lists['Inputs'])
-        hlo.addWidget(self.file_lists['Works'])
-        hlo.addWidget(self.file_lists['Outputs'])
-        hlo.setSpacing(2)
-        hlo.setMargin(0)
-        self.setLayout(hlo)
+        glo = QtWidgets.QGridLayout()
+        glo.addWidget(self.file_lists['Inputs'], 0, 0)
+        glo.addWidget(self.file_lists['Works'], 0, 1)
+        glo.addWidget(self.file_lists['Outputs'], 0, 2)
+        glo.addWidget(self.file_buttons, 1, 0, 1, 3)
+        glo.setSpacing(2)
+        glo.setMargin(0)
+        self.setLayout(glo)
     
     def clear_list_selection(self, file_type):
         self.file_lists[file_type].clearSelection()
