@@ -99,10 +99,10 @@ class JobsNodeSession(KabaretSession):
                 if job is not None:
                     #self._process_job(job)
                     working_job_popen = self.jobs_actor.node_execute_job(job)
-                    self.log_info('Jobs Node worker started. PID:', working_job_popen.pid)
+                    self.log_info('Jobs Node worker started. PID: {}'.format(working_job_popen.pid))
             
             else:
-                self.log_debug('Jobs Node worker in progress. PID:', working_job_popen.pid)
+                self.log_debug('Jobs Node worker in progress. PID: {}'.format(working_job_popen.pid))
 
             time.sleep(1)
 
